==> haskell-th-abstraction-0.2.7.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-abstraction
version: 0.2.7.0
id: th-abstraction-0.2.7.0-K3VY5rzhCFL2FVEMFfolof
key: th-abstraction-0.2.7.0-K3VY5rzhCFL2FVEMFfolof
license: ISC
copyright: 2017 Eric Mertens
maintainer: emertens@gmail.com
author: Eric Mertens
homepage: https://github.com/glguy/th-abstraction
synopsis: Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.
category: Development
abi: 35b0c81646e1b531707072bc72d3020b
exposed: True
exposed-modules:
    Language.Haskell.TH.Datatype
hidden-modules: Language.Haskell.TH.Datatype.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-abstraction-0.2.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-abstraction-0.2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/th-abstraction-0.2.7.0
hs-libraries: HSth-abstraction-0.2.7.0-K3VY5rzhCFL2FVEMFfolof
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0 template-haskell-2.13.0.0
    containers-0.5.11.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock
haddock-html: /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-abstraction-0.2.8.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-abstraction
version: 0.2.8.0
id: th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88
key: th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88
license: ISC
copyright: 2017 Eric Mertens
maintainer: emertens@gmail.com
author: Eric Mertens
homepage: https://github.com/glguy/th-abstraction
synopsis: Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.
category: Development
abi: 303b2de9b3dc2b2e86b6ff0f8de41846
exposed: True
exposed-modules:
    Language.Haskell.TH.Datatype
hidden-modules: Language.Haskell.TH.Datatype.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-abstraction-0.2.8.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-abstraction-0.2.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/th-abstraction-0.2.8.0
hs-libraries: HSth-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0 template-haskell-2.13.0.0
    containers-0.5.11.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock
haddock-html: /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
